;;; nndoc-freshmeat.el -- dissect freshmeat newsletters
;; Copyright (C) 1999  Peter von der Ah

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program; if not, write to the Free Software
;; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

(require 'nndoc)

(setq nndoc-freshmeat-delim "\n *--- - --- ------ - --- -- - - - -- -\n\n")

(nndoc-add-type
 `(freshmeat
   (first-article . "^  \\[ article details \\]\n\n")
   (article-begin . ,nndoc-freshmeat-delim)
   (file-end . "\nthat's it for today")
   (generate-head-function . nndoc-freshmeat-parts-head)
   (prepare-body-function . nndoc-freshmeat-strip-delim))
 'first)

(defun nndoc-freshmeat-strip-delim ()
  (while (re-search-forward nndoc-freshmeat-delim nil t)
    (replace-match "")))

(defun nndoc-freshmeat-type-p ()
  (when (re-search-forward "^subject: \\[fm/news\\]" nil t)
    t))

;; Derived from nndoc-generate-clari-briefs-head
(defun nndoc-freshmeat-parts-head (article)
  (let ((entry (cdr (assq article nndoc-dissection-alist)))
	subject from date)
    (save-excursion
      (set-buffer nndoc-current-buffer)
      (save-restriction
	(narrow-to-region (car entry) (nth 3 entry))
	(goto-char (point-min))
	(when (looking-at "^ *subject: \\(.*\\)$")
	  (setq subject (match-string 1)))
	(when (and (equal (forward-line 1) 0)
		   (looking-at "^ *added by: \\(.*\\) on \\(\\(Jan\\|Feb\\|Mar\\|Apr\\|May\\|Jun\\|Jul\\|Aug\\|Sep\\|Oct\\|Nov\\|Dec\\).*\\)$"))
	  (setq from (match-string 1)
		date (match-string 2)))))
    (insert "From: freshd@freshmeat.net (" (or from "unknown") ")"
	    (when date "\nDate: " date)
	    "\nSubject: " (or subject "(no subject)"))))
